@@ -471,12 +471,16 @@ polarPlot <-
     correlation_stats <- c(
       "r", "slope", "intercept", "robust_slope",
       "robust_intercept", "quantile_slope",
-      "quantile_intercept", "Pearson", "Spearman"
+      "quantile_intercept", "Pearson", "Spearman", "trend"
     )
 
     if (statistic %in% correlation_stats && length(pollutant) != 2) {
       stop("Correlation statistic requires two pollutants.")
     }
+    
+    # if statistic is trend, then don't force to be positive
+    if (statistic == "trend")
+      force.positive <- FALSE
 
     # names of variables for use later
     nam.x <- x
@@ -768,6 +772,18 @@ polarPlot <-
           ))
 
         binned <- binned$conc
+        
+      } else if (toupper(statistic) == "TREND") {
+        binned <- rowwise(ws.wd) %>%
+          do(simple_kernel_trend(
+            ., mydata,
+            x = nam.x, y = nam.wd, pollutant = pollutant, "date",
+            ws_spread = ws_spread, wd_spread = wd_spread, kernel,
+            tau = tau
+          ))
+        
+        binned <- binned$conc  
+        
       } else {
         binned <- rowwise(ws.wd) %>%
           do(calculate_weighted_statistics(
@@ -934,6 +950,14 @@ polarPlot <-
       id <- which(res$z < -1)
       if (length(id) > 0) res$z[id] <- -1
     }
+    
+    # annotation for trend statistic
+    if (statistic == "trend") {
+      if (missing(key.footer)) {
+        key.footer <- paste0(pollutant[1], " / year")
+      }
+    }
+    
 
     # Labels for correlation and regression, keep lower case like other labels
     if (statistic %in% c("r", "Pearson")) key.header <- expression(italic("Pearson\ncorrelation"))
@@ -1170,6 +1194,68 @@ simple_kernel <- function(data, mydata, x = "ws",
   return(data.frame(conc = conc))
 }
 
+# function to to kernel weighting of a quantile regression trend
+simple_kernel_trend <- function(data, mydata, x = "ws",
+                          y = "wd", pollutant, date,
+                          ws_spread, wd_spread, kernel, tau) {
+  # Centres
+  ws1 <- data[[1]]
+  wd1 <- data[[2]]
+  
+  # Gaussian kernel for wd
+  
+  # Scale wd
+  mydata$wd.scale <- mydata[[y]] - wd1
+  
+  # get correct angular distance
+  mydata$wd.scale <- (mydata$wd.scale + 180) %% 360 - 180
+  
+  # Scale with kernel
+  mydata$wd.scale <- mydata$wd.scale * 2 * pi / 360
+  
+  # Scale with kernel
+  mydata$wd.scale <- (2 * pi)^-0.5 * exp(-0.5 * (mydata$wd.scale / (2 * pi * wd_spread / 360))^2)
+  
+  # Scale ws
+  mydata$ws.scale <- (mydata[[x]] - ws1) / (max(mydata[[x]]) - min(mydata[[x]]))
+  
+  # Apply kernel smoother
+  mydata$ws.scale <- (2 * pi)^-0.5 * exp(-0.5 * (mydata$ws.scale / (ws_spread / (max(mydata[[x]]) - min(mydata[[x]]))))^2)
+  
+  mydata$weights <- mydata$wd.scale * mydata$ws.scale
+  
+  # quantreg is a Suggests package, so make sure it is there
+  try_require("quantreg", "polarPlot")
+  
+  # don't fit all data - takes too long with no gain
+  mydata <- filter(mydata, weights > 0.00001)
+  
+  # Drop dplyr's data frame for formula
+  mydata <- data.frame(mydata)
+  
+  # Build model
+  suppressWarnings(
+    fit <- try(quantreg::rq(
+      mydata[[pollutant[1]]] ~ mydata[[date]],
+      tau = tau,
+      weights = mydata[["weights"]], method = "fn"
+    ), TRUE)
+  )
+  
+  # Extract statistics
+  if (!inherits(fit, "try-error")) {
+    
+    # Extract statistics
+    slope = 365.25 * 24 * 3600 * fit$coefficients[2]
+    
+  } else {
+    slope <-  NA
+  }
+  
+  
+  return(data.frame(conc = slope))
+}
+
 
 # No export
 calculate_weighted_statistics <- function(data, mydata, statistic, x = "ws",
@@ -1184,7 +1270,7 @@ calculate_weighted_statistics <- function(data, mydata, statistic, x = "ws",
   mydata$ws.scale <- (mydata[[x]] - ws1) / (max(mydata[[x]]) - min(mydata[[x]]))
 
   # Apply kernel smoother
-  mydata$ws.scale <- (2 * pi)^-0.5 * exp(-0.5 * (mydata$ws.scale / (ws_spread / (max(mydata[[x]]) - min(mydata[[x]]))))^2)
+  mydata$ws.scale <- (2 * pi) ^ -0.5 * exp(-0.5 * (mydata$ws.scale / (ws_spread / (max(mydata[[x]]) - min(mydata[[x]]))))^2)
 
   # Scale wd
   mydata$wd.scale <- mydata[[y]] - wd1
@@ -1197,7 +1283,7 @@ calculate_weighted_statistics <- function(data, mydata, statistic, x = "ws",
   mydata$wd.scale <- mydata$wd.scale * 2 * pi / 360
 
   # Apply kernel smoother
-  mydata$wd.scale <- (2 * pi)^-0.5 * exp(-0.5 * (mydata$wd.scale / (2 * pi * wd_spread / 360))^2)
+  mydata$wd.scale <- (2 * pi) ^ -0.5 * exp(-0.5 * (mydata$wd.scale / (2 * pi * wd_spread / 360))^2)
 
   # Final weighting multiplies two kernels for ws and wd
   mydata$weight <- mydata$ws.scale * mydata$wd.scale
@@ -1210,7 +1296,7 @@ calculate_weighted_statistics <- function(data, mydata, statistic, x = "ws",
   thedata <- thedata[complete.cases(thedata), ]
 
   # don't fit all data - takes too long with no gain
-  thedata <- filter(thedata, weight > 0.001)
+  thedata <- filter(thedata, weight > 0.00001)
 
   # useful for showing what the weighting looks like as a surface
   # openair::scatterPlot(mydata, x = "ws", y = "wd", z = "weight", method = "level")
