@@ -266,7 +266,8 @@ timeAverage <- function(mydata, avg.time = "day", data.thresh = 0,
 
     if (!is.na(end.date)) {
       lastLine <- data.frame(date = as.POSIXct(end.date, tz = TZ))
-      lastLine[[type]] <- mydata[[type]][1]
+      #lastLine[[type]] <- mydata[[type]][1]
+      lastLine[type] <- mydata[1, type]
 
       mydata <- bind_rows(mydata, lastLine)
 
@@ -448,10 +449,10 @@ timeAverage <- function(mydata, avg.time = "day", data.thresh = 0,
       if (statistic == "mean") { ## faster for some reason?
         
         avmet <- group_by(mydata, UQS(syms(vars))) %>%
-          summarise_all(
-            funs(
-              if (sum(is.na(.)) / length(.) <= 1 - data.thresh) {
-                mean(., na.rm = TRUE)
+          summarise(
+            across(everything(),
+              ~ if (sum(is.na(.x)) / length(.x) <= 1 - data.thresh) {
+                mean(.x, na.rm = TRUE)
               } else {
                 NA
               }
@@ -459,10 +460,10 @@ timeAverage <- function(mydata, avg.time = "day", data.thresh = 0,
           )
       } else {
         avmet <- group_by(mydata, UQS(syms(vars))) %>%
-          summarise_all(
-            funs(
-              if (sum(is.na(.)) / length(.) <= 1 - data.thresh) {
-                FUN(.)
+          summarise(
+            across(everything(),
+              ~ if (sum(is.na(.x)) / length(.x) <= 1 - data.thresh) {
+                FUN(.x)
               } else {
                 NA
               }
@@ -482,9 +483,11 @@ timeAverage <- function(mydata, avg.time = "day", data.thresh = 0,
 
       # This is much faster for some reason
       if (statistic == "mean") {
-        avmet <- avmet %>% summarise_all(funs(mean(., na.rm = TRUE)))
+        avmet <- avmet %>% 
+          summarise(across(everything(), ~mean(.x, na.rm = TRUE)))
       } else {
-        avmet <- avmet %>% summarise_all(funs(FUN(.)))
+        avmet <- avmet %>% 
+          summarise(across(everything(), ~FUN(.x)))
       }
     }
 
